Learn R Programming

overlapping (version 2.5)

check.missing: Check for missing data

Description

Remove NAs from the x list.

Usage

check.missing( x )

Value

It returns the list x without NAs.

Arguments

x

a list of numerical vectors to be compared (each vector is an element of the list).

Author

Massimiliano Pastore

Details

If list x contains NAs, it returns a warning and removes missing cases using na.omit().

Examples

Run this code
set.seed(20150605)
x <- list(X1=rnorm(10), X2=rt(10,8))
check.missing( x )

x$X1[1:5] <- NA
check.missing( x )

Run the code above in your browser using DataLab