powered by
Remove NAs from the x list.
NAs
x
check.missing( x )
It returns the list x without NAs.
a list of numerical vectors to be compared (each vector is an element of the list).
Massimiliano Pastore
If list x contains NAs, it returns a warning and removes missing cases using na.omit().
na.omit()
set.seed(20150605) x <- list(X1=rnorm(10), X2=rt(10,8)) check.missing( x ) x$X1[1:5] <- NA check.missing( x )
Run the code above in your browser using DataLab